
#
# Internal schema definition of tables defined for a site.
#

#
# RepublishInfo Definition
#

CREATE TABLE RepublishInfo (
    MeasurementDate DATE NOT NULL DEFAULT "000-00-00",
    MeasurementTime TIME NOT NULL DEFAULT "00:00:00",
    VOList TEXT 
);

#
# SpecRecords Definition
#

CREATE TABLE SpecRecords (
    SpecID VARCHAR(255) PRIMARY KEY,
    SiteName VARCHAR(50) NOT NULL,
    ClusterID VARCHAR(50),
    SubClusterID VARCHAR(50),
	SpecInt2000 INT,
    SpecFloat2000 INT,
    EndDate DATE,
    EndTime TIME,
    MeasurementDate DATE NOT NULL DEFAULT "000-00-00",
    MeasurementTime TIME NOT NULL DEFAULT "00:00:00",
    INDEX LcgJoin (SiteName)
);

#
# GkRecords Definition
#

CREATE TABLE GkRecords (
    GkID VARCHAR(255) PRIMARY KEY,
    GramScriptJobID VARCHAR(100) NOT NULL,
    LocalJobID VARCHAR(50),
    Processed INT,
    GlobalUserName VARCHAR(255),
    SiteName VARCHAR(50) NOT NULL,
    ValidFrom DATE,
    ValidUntil DATE,
    INDEX LcgJoin (GramScriptJobID)
);

#
# MessageRecords Definition
#

CREATE TABLE MessageRecords (
    MsgID VARCHAR(200) PRIMARY KEY,
    GramScriptJobID VARCHAR(100) NOT NULL,
    JobName VARCHAR(60) NOT NULL,
    Processed INT,
    SiteName VARCHAR(50) NOT NULL,
    ValidFrom DATE,
    ValidUntil DATE,
    INDEX LcgJoin (JobName)
);

#
# PbsRecord Definition
#

CREATE TABLE EventRecords (
    EventID VARCHAR(255) PRIMARY KEY,
    SiteName VARCHAR(50) NOT NULL,
    JobName VARCHAR(60) NOT NULL,
    LocalUserID VARCHAR(20),
    LocalUserGroup VARCHAR(20),
    WallDuration VARCHAR(30),
    CpuDuration VARCHAR(30),
    WallDurationSeconds INT,
    CpuDurationSeconds INT,
    StartTime VARCHAR(30),
    StopTime VARCHAR(30),
    StartTimeUTC VARCHAR(30),
    StopTimeUTC VARCHAR(30),
    StartTimeEpoch INT,
    StopTimeEpoch INT,
    SubmitHost VARCHAR(50) NOT NULL,
    MemoryReal INT,
    MemoryVirtual INT,
    Processed INT,
    EventDate DATE NOT NULL DEFAULT "000-00-00",
    EventTime TIME NOT NULL DEFAULT "00:00:00",
    INDEX LcgJoin_SiteName (SiteName),
    INDEX LcgJoin_JobName (JobName)
);

CREATE TABLE LcgRecords (
    RecordIdentity VARCHAR(255) PRIMARY KEY,
    ExecutingSite VARCHAR(50),
    LocalJobID VARCHAR(50),
    LCGJobID VARCHAR(50),
    LocalUserID VARCHAR(50),
    LCGUserID VARCHAR(255),
    LCGUserVO VARCHAR(50),
    ElapsedTime VARCHAR(30),
    BaseCpuTime VARCHAR(30),
    ElapsedTimeSeconds INT,
    BaseCpuTimeSeconds INT,
    StartTime VARCHAR(30),
    StopTime VARCHAR(30),
    StartTimeUTC VARCHAR(30),
    StopTimeUTC VARCHAR(30),
    StartTimeEpoch INT,
    StopTimeEpoch INT,
    ExecutingCE VARCHAR(50),
    MemoryReal INT,
    MemoryVirtual INT,
    SpecInt2000 INT,
    SpecFloat2000 INT,
    EventDate DATE NOT NULL DEFAULT "000-00-00",
    EventTime TIME NOT NULL DEFAULT "00:00:00",
    MeasurementDate DATE NOT NULL DEFAULT "000-00-00",
    MeasurementTime TIME NOT NULL DEFAULT "00:00:00"
);

#
# LcgProcessedFiles Definition
#

CREATE TABLE LcgProcessedFiles (
     FileName VARCHAR(100),
     FileType CHAR(1),
     SiteName VARCHAR(50),
     FilePath VARCHAR(255),
     HostName VARCHAR(255),
     PRIMARY KEY (FileName, FileType, SiteName)
);

